@@ -105,7 +105,8 @@ class KubeModel(ABC):
         """
         optimizer = self.configure_optimizers()
         self.optimizer = optimizer
-  
+        self.logger.debug(f"Configure optimizer at epoch: {self.epoch}")
+
         # TODO here the state loaded should be the averaged one not the saved from earlier
 
         # self._load_optimizer_state()
@@ -415,10 +416,6 @@ class KubeModel(ABC):
                     loss += self.train(batch, idx)
                     # self.logger.debug(f'loss is {loss}, iterations are {num_iterations}')
 
-                    # update model and parameter
-                    loss.backward()
-                    self.optimizer.step()
-
                 self._on_iteration_end()
             except RedisError as re:
                 raise StorageError(re)
